==> libcommons-fileupload-java_1.3.orig.tar.gz: commons-fileupload-1.3-src/src/test/java/org/apache/commons/fileupload/HttpServletRequestFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.fileupload;

import javax.servlet.http.HttpServletRequest;

/**
 * @version $Id: HttpServletRequestFactory.java 1454693 2013-03-09 12:30:27Z simonetripodi $
 */
final class HttpServletRequestFactory {

    static public HttpServletRequest createHttpServletRequestWithNullContentType() {
        byte[] requestData = "foobar".getBytes();
        return new MockHttpServletRequest(
                            requestData,
                            null);
    }

    static public HttpServletRequest createValidHttpServletRequest(
            final String[] strFileNames) {
        // todo - provide a real implementation

        StringBuffer sbRequestData = new StringBuffer();

        for (int i = 0; i < strFileNames.length; i++)
        {
            sbRequestData.append(strFileNames[i]);
        }

        byte[] requestData = null;
        requestData = sbRequestData.toString().getBytes();

        return new MockHttpServletRequest(
                            requestData,
                            FileUploadBase.MULTIPART_FORM_DATA);
    }

    static public HttpServletRequest createInvalidHttpServletRequest() {
        byte[] requestData = "foobar".getBytes();
        return new MockHttpServletRequest(
                            requestData,
                            FileUploadBase.MULTIPART_FORM_DATA);
    }

}

==> libcommons-fileupload-java_1.3.1.orig.tar.gz: commons-fileupload-1.3.1-src/src/test/java/org/apache/commons/fileupload/HttpServletRequestFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.fileupload;

import javax.servlet.http.HttpServletRequest;

/**
 * @version $Id: HttpServletRequestFactory.java 1565246 2014-02-06 13:40:52Z ggregory $
 */
final class HttpServletRequestFactory {

    static public HttpServletRequest createHttpServletRequestWithNullContentType() {
        byte[] requestData = "foobar".getBytes();
        return new MockHttpServletRequest(
                            requestData,
                            null);
    }

    static public HttpServletRequest createValidHttpServletRequest(
            final String[] strFileNames) {
        // todo - provide a real implementation

        StringBuilder sbRequestData = new StringBuilder();

        for (String strFileName : strFileNames) {
            sbRequestData.append(strFileName);
        }

        byte[] requestData = null;
        requestData = sbRequestData.toString().getBytes();

        return new MockHttpServletRequest(
                            requestData,
                            FileUploadBase.MULTIPART_FORM_DATA);
    }

    static public HttpServletRequest createInvalidHttpServletRequest() {
        byte[] requestData = "foobar".getBytes();
        return new MockHttpServletRequest(
                            requestData,
                            FileUploadBase.MULTIPART_FORM_DATA);
    }

}
